Class: RSpec::JsonMatchers::Expectations::Core::CompositeExpectation Abstract

Inherits:
CallableExpectation show all
Extended by:
AbstractClass
Defined in:
lib/rspec/json_matchers/expectations/core.rb

Overview

This class is abstract.

Takes any number of objects and converts into expectation objects (if not already)

Class Method Summary collapse

Methods inherited from RSpec::JsonMatchers::Expectation

build, build_many, #expect?

Class Method Details

.[](*values) ⇒ Expectation

The replacement of new It accept any number of arguments and delegates to private new This pattern is taken from gem contracts

Also all values will be converted into expectations

Returns:

See Also:



92
93
94
# File 'lib/rspec/json_matchers/expectations/core.rb', line 92

def self.[](*values)
  super(build_many(values))
end