Module: RSpec::JsonMatchers::Expectations::Private

Defined in:
lib/rspec/json_matchers/expectations/private.rb

Overview

All classes in this module are internal expectations used when non-expectation object/class is passed in Extension gems should have their own namespace and should NOT add new classes to this namespace Classes here have dependency on Core & Mixins::BuiltIn

TODO: Remove dependency on Mixins::BuiltIn

Defined Under Namespace

Classes: ArrayWithSize, Eq, InRange, KindOf, MatchingRegexp, Nothing, SatisfyingCallable