Class: RSpec::JsonMatchers::Expectations::Private::KindOf

Inherits:
Core::SingleValueCallableExpectation show all
Defined in:
lib/rspec/json_matchers/expectations/private.rb

Overview

Note:

Might use a whitelist of acceptable classes and raise error if other things passed in in the future

Takes exactly one object Use stored class for checking value

Instance Method Summary collapse

Methods inherited from Core::SingleValueCallableExpectation

[]

Methods inherited from Core::CallableExpectation

[]

Methods inherited from RSpec::JsonMatchers::Expectation

build, build_many

Instance Method Details

#expect?(value) ⇒ Boolean

Returns:

  • (Boolean)


54
55
56
# File 'lib/rspec/json_matchers/expectations/private.rb', line 54

def expect?(value)
  value.is_a?(expected_class)
end