Module: RSpec::JsonMatchers::Expectations::Abstract
- Defined in:
- lib/rspec/json_matchers/expectations/abstract.rb
Overview
Classes in this namespace are depending on Core and depended by some classes in Mixins::BuiltIn They are all abstract too, thus the naming, but might change This namespace is created is to avoid require order problem when putting classes here in Private
Defined Under Namespace
Classes: NumericExpectation