Class: RSpec::JsonMatchers::Expectations::Core::CallableExpectation Abstract
- Inherits:
-
RSpec::JsonMatchers::Expectation
- Object
- RSpec::JsonMatchers::Expectation
- RSpec::JsonMatchers::Expectations::Core::CallableExpectation
- Extended by:
- AbstractClass
- Defined in:
- lib/rspec/json_matchers/expectations/core.rb
Overview
This class is abstract.
This class MUST be used after being inherited
Allow class to be called with .[] instead of .new
Direct Known Subclasses
Class Method Summary collapse
-
.[](*values) ⇒ Expectation
The replacement of new It accept any number of arguments and delegates to private new This pattern is taken from gem
contracts.
Methods inherited from RSpec::JsonMatchers::Expectation
Class Method Details
.[](*values) ⇒ Expectation
The replacement of new It accept any number of arguments and delegates to private new This pattern is taken from gem contracts
56 57 58 |
# File 'lib/rspec/json_matchers/expectations/core.rb', line 56 def self.[](*values) new(*values) end |