Class: RSpec::JsonMatchers::Expectations::Core::CompositeExpectation Abstract
- Inherits:
-
CallableExpectation
- Object
- RSpec::JsonMatchers::Expectation
- CallableExpectation
- RSpec::JsonMatchers::Expectations::Core::CompositeExpectation
- Extended by:
- AbstractClass
- Defined in:
- lib/rspec/json_matchers/expectations/core.rb
Overview
This class is abstract.
Takes any number of objects and converts into expectation objects (if not already)
Direct Known Subclasses
Class Method Summary collapse
-
.[](*values) ⇒ Expectation
The replacement of new It accept any number of arguments and delegates to private new This pattern is taken from gem
contracts.
Methods inherited from RSpec::JsonMatchers::Expectation
Class Method Details
.[](*values) ⇒ Expectation
The replacement of new It accept any number of arguments and delegates to private new This pattern is taken from gem contracts
Also all values will be converted into expectations
92 93 94 |
# File 'lib/rspec/json_matchers/expectations/core.rb', line 92 def self.[](*values) super(build_many(values)) end |