Module: RSpec::JsonMatchers::Expectations::Mixins
- Defined in:
- lib/rspec/json_matchers/expectations/mixins/built_in.rb
Overview
If this gem or extensions gems decide to add different groups of expectations classes Which aim to be included in example groups They should add the namespace modules here
Defined Under Namespace
Modules: BuiltIn